@@ -1,7 +1,7 @@
 package gojq
 
 type code struct {
-	v  interface{}
+	v  any
 	op opcode
 }
 
@@ -25,13 +25,15 @@ const (
 	opbacktrack
 	opjump
 	opjumpifnot
+	opindex
+	opindexarray
 	opcall
 	opcallrec
 	oppushpc
 	opcallpc
 	opscope
 	opret
-	opeach
+	opiter
 	opexpbegin
 	opexpend
 	oppathbegin
@@ -74,6 +76,10 @@ func (op opcode) String() string {
 		return "jump"
 	case opjumpifnot:
 		return "jumpifnot"
+	case opindex:
+		return "index"
+	case opindexarray:
+		return "indexarray"
 	case opcall:
 		return "call"
 	case opcallrec:
@@ -86,8 +92,8 @@ func (op opcode) String() string {
 		return "scope"
 	case opret:
 		return "ret"
-	case opeach:
-		return "each"
+	case opiter:
+		return "iter"
 	case opexpbegin:
 		return "expbegin"
 	case opexpend:
