@@ -6,20 +6,16 @@ import (
 )
 
 // Compare l and r, and returns jq-flavored comparison value.
-//
-//   -1 if l <  r
-//    0 if l == r
-//   +1 if l >  r
-//
+// The result will be 0 if l == r, -1 if l < r, and +1 if l > r.
 // This comparison is used by built-in operators and functions.
-func Compare(l, r interface{}) int {
+func Compare(l, r any) int {
 	return compare(l, r)
 }
 
-func compare(l, r interface{}) int {
+func compare(l, r any) int {
 	return binopTypeSwitch(l, r,
 		compareInt,
-		func(l, r float64) interface{} {
+		func(l, r float64) any {
 			switch {
 			case l < r || math.IsNaN(l):
 				return -1
@@ -29,10 +25,10 @@ func compare(l, r interface{}) int {
 				return 1
 			}
 		},
-		func(l, r *big.Int) interface{} {
+		func(l, r *big.Int) any {
 			return l.Cmp(r)
 		},
-		func(l, r string) interface{} {
+		func(l, r string) any {
 			switch {
 			case l < r:
 				return -1
@@ -42,7 +38,7 @@ func compare(l, r interface{}) int {
 				return 1
 			}
 		},
-		func(l, r []interface{}) interface{} {
+		func(l, r []any) any {
 			n := len(l)
 			if len(r) < n {
 				n = len(r)
@@ -54,25 +50,25 @@ func compare(l, r interface{}) int {
 			}
 			return compareInt(len(l), len(r))
 		},
-		func(l, r map[string]interface{}) interface{} {
+		func(l, r map[string]any) any {
 			lk, rk := funcKeys(l), funcKeys(r)
 			if cmp := compare(lk, rk); cmp != 0 {
 				return cmp
 			}
-			for _, k := range lk.([]interface{}) {
+			for _, k := range lk.([]any) {
 				if cmp := compare(l[k.(string)], r[k.(string)]); cmp != 0 {
 					return cmp
 				}
 			}
 			return 0
 		},
-		func(l, r interface{}) interface{} {
+		func(l, r any) any {
 			return compareInt(typeIndex(l), typeIndex(r))
 		},
 	).(int)
 }
 
-func compareInt(l, r int) interface{} {
+func compareInt(l, r int) any {
 	switch {
 	case l < r:
 		return -1
@@ -83,7 +79,7 @@ func compareInt(l, r int) interface{} {
 	}
 }
 
-func typeIndex(v interface{}) int {
+func typeIndex(v any) int {
 	switch v := v.(type) {
 	default:
 		return 0
@@ -96,9 +92,9 @@ func typeIndex(v interface{}) int {
 		return 3
 	case string:
 		return 4
-	case []interface{}:
+	case []any:
 		return 5
-	case map[string]interface{}:
+	case map[string]any:
 		return 6
 	}
 }
