@@ -5,37 +5,38 @@ import "context"
 type env struct {
 	pc        int
 	stack     *stack
-	scopes    *stack
 	paths     *stack
-	values    []interface{}
+	scopes    *scopeStack
+	values    []any
 	codes     []*code
 	codeinfos []codeinfo
-	forks     []*fork
+	forks     []fork
 	backtrack bool
 	offset    int
 	expdepth  int
-	args      [32]interface{} // len(env.args) > maxarity
+	label     int
+	args      [32]any // len(env.args) > maxarity
 	ctx       context.Context
 }
 
 func newEnv(ctx context.Context) *env {
 	return &env{
 		stack:  newStack(),
-		scopes: newStack(),
 		paths:  newStack(),
+		scopes: newScopeStack(),
 		ctx:    ctx,
 	}
 }
 
 type scope struct {
-	id        int
-	offset    int
-	pc        int
-	saveindex int
+	id         int
+	offset     int
+	pc         int
+	saveindex  int
+	outerindex int
 }
 
 type fork struct {
-	op         opcode
 	pc         int
 	stackindex int
 	stacklimit int
