@@ -51,7 +51,7 @@ func TestWithModuleLoaderError(t *testing.T) {
 
 func TestWithModuleLoader_modulemeta(t *testing.T) {
 	query, err := gojq.Parse(`
-		"module1" | modulemeta
+		"module1", "module2" | modulemeta
 	`)
 	if err != nil {
 		t.Fatal(err)
@@ -64,32 +64,42 @@ func TestWithModuleLoader_modulemeta(t *testing.T) {
 		t.Fatal(err)
 	}
 	iter := code.Run(nil)
+	n := 0
 	for {
 		got, ok := iter.Next()
 		if !ok {
 			break
 		}
-		if expected := map[string]interface{}{
-			"deps": []interface{}{
-				map[string]interface{}{
-					"relpath": "module2",
-					"as":      "foo",
-					"is_data": false,
+		if n == 0 {
+			if expected := map[string]any{
+				"deps": []any{
+					map[string]any{
+						"relpath": "module2",
+						"as":      "foo",
+						"is_data": false,
+					},
 				},
-			},
-			"name": "module1",
-			"test": 42,
-		}; !reflect.DeepEqual(got, expected) {
-			t.Errorf("expected: %v, got: %v", expected, got)
+				"name": "module1",
+				"test": 42,
+			}; !reflect.DeepEqual(got, expected) {
+				t.Errorf("expected: %v, got: %v", expected, got)
+			}
+		} else {
+			if expected := map[string]any{
+				"deps": []any{}, // not a nil-slice
+			}; !reflect.DeepEqual(got, expected) {
+				t.Errorf("expected: %v, got: %v", expected, got)
+			}
 		}
+		n++
 	}
 }
 
 type moduleLoaderJSON struct{}
 
-func (*moduleLoaderJSON) LoadJSON(name string) (interface{}, error) {
+func (*moduleLoaderJSON) LoadJSON(name string) (any, error) {
 	if name == "module1" {
-		return []interface{}{1.0, 42, json.Number("123")}, nil
+		return []any{1.0, 42, json.Number("123")}, nil
 	}
 	return nil, fmt.Errorf("module not found: %q", name)
 }
@@ -115,7 +125,7 @@ func TestWithModuleLoader_JSON(t *testing.T) {
 		if !ok {
 			break
 		}
-		if expected := []interface{}{[]interface{}{1.0, 42, 123}, 5166}; !reflect.DeepEqual(got, expected) {
+		if expected := []any{[]any{1.0, 42, 123}, 5166}; !reflect.DeepEqual(got, expected) {
 			t.Errorf("expected: %v, got: %v", expected, got)
 		}
 	}
@@ -178,7 +188,7 @@ func TestWithEnvironLoader(t *testing.T) {
 		if !ok {
 			break
 		}
-		expected := map[string]interface{}{"foo": "42", "bar": "128", "qux": ""}
+		expected := map[string]any{"foo": "42", "bar": "128", "qux": ""}
 		if !reflect.DeepEqual(got, expected) {
 			t.Errorf("expected: %v, got: %v", expected, got)
 		}
@@ -200,7 +210,7 @@ func TestWithEnvironLoaderEmpty(t *testing.T) {
 		if !ok {
 			break
 		}
-		if expected := map[string]interface{}{}; !reflect.DeepEqual(got, expected) {
+		if expected := map[string]any{}; !reflect.DeepEqual(got, expected) {
 			t.Errorf("expected: %v, got: %v", expected, got)
 		}
 	}
@@ -287,13 +297,13 @@ func TestWithVariablesError2(t *testing.T) {
 
 func TestWithFunction(t *testing.T) {
 	options := []gojq.CompilerOption{
-		gojq.WithFunction("f", 0, 0, func(x interface{}, _ []interface{}) interface{} {
+		gojq.WithFunction("f", 0, 0, func(x any, _ []any) any {
 			if x, ok := x.(int); ok {
 				return x * 2
 			}
 			return fmt.Errorf("f cannot be applied to: %v", x)
 		}),
-		gojq.WithFunction("g", 1, 1, func(x interface{}, xs []interface{}) interface{} {
+		gojq.WithFunction("g", 1, 1, func(x any, xs []any) any {
 			if x, ok := x.(int); ok {
 				if y, ok := xs[0].(int); ok {
 					return x + y
@@ -310,7 +320,7 @@ func TestWithFunction(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	iter := code.Run([]interface{}{0, 1, 2, 3, 4})
+	iter := code.Run([]any{0, 1, 2, 3, 4})
 	n := 0
 	for {
 		v, ok := iter.Next()
@@ -354,13 +364,13 @@ func TestWithFunction(t *testing.T) {
 
 func TestWithFunctionDuplicateName(t *testing.T) {
 	options := []gojq.CompilerOption{
-		gojq.WithFunction("f", 0, 0, func(x interface{}, _ []interface{}) interface{} {
+		gojq.WithFunction("f", 0, 0, func(x any, _ []any) any {
 			if x, ok := x.(int); ok {
 				return x * 2
 			}
 			return fmt.Errorf("f cannot be applied to: %v", x)
 		}),
-		gojq.WithFunction("f", 1, 1, func(x interface{}, xs []interface{}) interface{} {
+		gojq.WithFunction("f", 1, 1, func(x any, xs []any) any {
 			if x, ok := x.(int); ok {
 				if y, ok := xs[0].(int); ok {
 					return x + y
@@ -368,13 +378,13 @@ func TestWithFunctionDuplicateName(t *testing.T) {
 			}
 			return fmt.Errorf("f cannot be applied to: %v, %v", x, xs)
 		}),
-		gojq.WithFunction("f", 0, 0, func(x interface{}, _ []interface{}) interface{} {
+		gojq.WithFunction("f", 0, 0, func(x any, _ []any) any {
 			if x, ok := x.(int); ok {
 				return x * 4
 			}
 			return fmt.Errorf("f cannot be applied to: %v", x)
 		}),
-		gojq.WithFunction("f", 2, 2, func(x interface{}, xs []interface{}) interface{} {
+		gojq.WithFunction("f", 2, 2, func(x any, xs []any) any {
 			if x, ok := x.(int); ok {
 				if y, ok := xs[0].(int); ok {
 					if z, ok := xs[1].(int); ok {
@@ -393,7 +403,7 @@ func TestWithFunctionDuplicateName(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	iter := code.Run([]interface{}{0, 1, 2, 3, 4})
+	iter := code.Run([]any{0, 1, 2, 3, 4})
 	n := 0
 	for {
 		v, ok := iter.Next()
@@ -437,7 +447,7 @@ func TestWithFunctionDuplicateName(t *testing.T) {
 
 func TestWithFunctionMultipleArities(t *testing.T) {
 	options := []gojq.CompilerOption{
-		gojq.WithFunction("f", 0, 4, func(x interface{}, xs []interface{}) interface{} {
+		gojq.WithFunction("f", 0, 4, func(x any, xs []any) any {
 			if x, ok := x.(int); ok {
 				x *= 2
 				for _, y := range xs {
@@ -449,7 +459,7 @@ func TestWithFunctionMultipleArities(t *testing.T) {
 			}
 			return fmt.Errorf("f cannot be applied to: %v, %v", x, xs)
 		}),
-		gojq.WithFunction("f", 2, 3, func(x interface{}, xs []interface{}) interface{} {
+		gojq.WithFunction("f", 2, 3, func(x any, xs []any) any {
 			if x, ok := x.(int); ok {
 				for _, y := range xs {
 					if y, ok := y.(int); ok {
@@ -460,7 +470,7 @@ func TestWithFunctionMultipleArities(t *testing.T) {
 			}
 			return fmt.Errorf("f cannot be applied to: %v, %v", x, xs)
 		}),
-		gojq.WithFunction("g", 0, 30, func(x interface{}, xs []interface{}) interface{} {
+		gojq.WithFunction("g", 0, 30, func(x any, xs []any) any {
 			return nil
 		}),
 	}
@@ -472,7 +482,7 @@ func TestWithFunctionMultipleArities(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	iter := code.Run([]interface{}{0, 1, 2, 3, 4})
+	iter := code.Run([]any{0, 1, 2, 3, 4})
 	n := 0
 	for {
 		v, ok := iter.Next()
@@ -515,25 +525,25 @@ func TestWithFunctionMultipleArities(t *testing.T) {
 }
 
 type valueError struct {
-	v interface{}
+	v any
 }
 
 func (err *valueError) Error() string {
 	return "error: " + fmt.Sprint(err.v)
 }
 
-func (err *valueError) Value() interface{} {
+func (err *valueError) Value() any {
 	return err.v
 }
 
 func TestWithFunctionValueError(t *testing.T) {
-	expected := map[string]interface{}{"foo": 42}
+	expected := map[string]any{"foo": 42}
 	query, err := gojq.Parse("try f catch .")
 	if err != nil {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithFunction("f", 0, 0, func(x interface{}, _ []interface{}) interface{} {
+		gojq.WithFunction("f", 0, 0, func(x any, _ []any) any {
 			return &valueError{expected}
 		}),
 	)
@@ -558,7 +568,7 @@ func TestWithFunctionCompileArgsError(t *testing.T) {
 		t.Fatal(err)
 	}
 	_, err = gojq.Compile(query,
-		gojq.WithFunction("f", 0, 1, func(interface{}, []interface{}) interface{} {
+		gojq.WithFunction("f", 0, 1, func(any, []any) any {
 			return 0
 		}),
 	)
@@ -581,7 +591,7 @@ func TestWithFunctionArityError(t *testing.T) {
 				}
 			}()
 			t.Fatal(gojq.Compile(query,
-				gojq.WithFunction("f", tc.min, tc.max, func(interface{}, []interface{}) interface{} {
+				gojq.WithFunction("f", tc.min, tc.max, func(any, []any) any {
 					return 0
 				}),
 			))
@@ -595,10 +605,10 @@ func TestWithIterFunction(t *testing.T) {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithIterFunction("f", 0, 0, func(interface{}, []interface{}) gojq.Iter {
+		gojq.WithIterFunction("f", 0, 0, func(any, []any) gojq.Iter {
 			return gojq.NewIter(1, 2, 3)
 		}),
-		gojq.WithIterFunction("g", 2, 2, func(_ interface{}, xs []interface{}) gojq.Iter {
+		gojq.WithIterFunction("g", 2, 2, func(_ any, xs []any) gojq.Iter {
 			if x, ok := xs[0].(int); ok {
 				if y, ok := xs[1].(int); ok {
 					return &rangeIter{x, y}
@@ -606,7 +616,7 @@ func TestWithIterFunction(t *testing.T) {
 			}
 			return gojq.NewIter(fmt.Errorf("g cannot be applied to: %v", xs))
 		}),
-		gojq.WithIterFunction("h", 0, 0, func(interface{}, []interface{}) gojq.Iter {
+		gojq.WithIterFunction("h", 0, 0, func(any, []any) gojq.Iter {
 			return gojq.NewIter()
 		}),
 	)
@@ -636,7 +646,7 @@ func TestWithIterFunctionError(t *testing.T) {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithIterFunction("f", 0, 0, func(interface{}, []interface{}) gojq.Iter {
+		gojq.WithIterFunction("f", 0, 0, func(any, []any) gojq.Iter {
 			return gojq.NewIter(1, errors.New("error"), 3)
 		}),
 	)
@@ -677,7 +687,7 @@ func TestWithIterFunctionPathIndexing(t *testing.T) {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithIterFunction("f", 0, 0, func(interface{}, []interface{}) gojq.Iter {
+		gojq.WithIterFunction("f", 0, 0, func(any, []any) gojq.Iter {
 			return gojq.NewIter(0, 1, 2)
 		}),
 	)
@@ -690,7 +700,7 @@ func TestWithIterFunctionPathIndexing(t *testing.T) {
 		if !ok {
 			break
 		}
-		if expected := []interface{}{1, 1, 1}; !reflect.DeepEqual(v, expected) {
+		if expected := []any{1, 1, 1}; !reflect.DeepEqual(v, expected) {
 			t.Errorf("expected: %v, got: %v", expected, v)
 		}
 	}
@@ -702,7 +712,7 @@ func TestWithIterFunctionPathInputValue(t *testing.T) {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithIterFunction("f", 0, 0, func(v interface{}, _ []interface{}) gojq.Iter {
+		gojq.WithIterFunction("f", 0, 0, func(v any, _ []any) gojq.Iter {
 			return gojq.NewIter(v, v, v)
 		}),
 	)
@@ -715,7 +725,7 @@ func TestWithIterFunctionPathInputValue(t *testing.T) {
 		if !ok {
 			break
 		}
-		if expected := map[string]interface{}{"x": 1}; !reflect.DeepEqual(v, expected) {
+		if expected := map[string]any{"x": 1}; !reflect.DeepEqual(v, expected) {
 			t.Errorf("expected: %v, got: %v", expected, v)
 		}
 	}
@@ -727,7 +737,7 @@ func TestWithIterFunctionPathEmpty(t *testing.T) {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithIterFunction("f", 0, 0, func(interface{}, []interface{}) gojq.Iter {
+		gojq.WithIterFunction("f", 0, 0, func(any, []any) gojq.Iter {
 			return gojq.NewIter()
 		}),
 	)
@@ -740,7 +750,7 @@ func TestWithIterFunctionPathEmpty(t *testing.T) {
 		if !ok {
 			break
 		}
-		if expected := map[string]interface{}{"x": 0}; !reflect.DeepEqual(v, expected) {
+		if expected := map[string]any{"x": 0}; !reflect.DeepEqual(v, expected) {
 			t.Errorf("expected: %v, got: %v", expected, v)
 		}
 	}
@@ -752,8 +762,8 @@ func TestWithIterFunctionInvalidPathError(t *testing.T) {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithIterFunction("f", 0, 0, func(interface{}, []interface{}) gojq.Iter {
-			return gojq.NewIter(map[string]interface{}{"x": 1})
+		gojq.WithIterFunction("f", 0, 0, func(any, []any) gojq.Iter {
+			return gojq.NewIter(map[string]any{"x": 1})
 		}),
 	)
 	if err != nil {
@@ -779,7 +789,7 @@ func TestWithIterFunctionPathError(t *testing.T) {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithIterFunction("f", 0, 0, func(interface{}, []interface{}) gojq.Iter {
+		gojq.WithIterFunction("f", 0, 0, func(any, []any) gojq.Iter {
 			return gojq.NewIter(errors.New("error"))
 		}),
 	)
@@ -812,10 +822,10 @@ func TestWithIterFunctionDefineError(t *testing.T) {
 		}
 	}()
 	t.Fatal(gojq.Compile(query,
-		gojq.WithFunction("f", 0, 0, func(interface{}, []interface{}) interface{} {
+		gojq.WithFunction("f", 0, 0, func(any, []any) any {
 			return 0
 		}),
-		gojq.WithIterFunction("f", 0, 0, func(interface{}, []interface{}) gojq.Iter {
+		gojq.WithIterFunction("f", 0, 0, func(any, []any) gojq.Iter {
 			return gojq.NewIter()
 		}),
 	))
@@ -838,7 +848,7 @@ func TestWithFunctionWithModuleLoader(t *testing.T) {
 		t.Fatal(err)
 	}
 	code, err := gojq.Compile(query,
-		gojq.WithFunction("f", 0, 0, func(x interface{}, _ []interface{}) interface{} {
+		gojq.WithFunction("f", 0, 0, func(x any, _ []any) any {
 			if x, ok := x.(int); ok {
 				return x * 2
 			}
@@ -849,7 +859,7 @@ func TestWithFunctionWithModuleLoader(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	iter := code.Run([]interface{}{0, 1, 2, 3, 4})
+	iter := code.Run([]any{0, 1, 2, 3, 4})
 	n := 0
 	for {
 		v, ok := iter.Next()
