@@ -8,18 +8,18 @@ import "unicode/utf8"
 //
 // This method is used by error messages of built-in operators and functions,
 // and accepts only limited types (nil, bool, int, float64, *big.Int, string,
-// []interface{}, and map[string]interface{}). Note that the maximum width and
-// trailing strings on truncation may be changed in the future.
-func Preview(v interface{}) string {
+// []any, and map[string]any). Note that the maximum width and trailing strings
+// on truncation may be changed in the future.
+func Preview(v any) string {
 	bs := jsonLimitedMarshal(v, 32)
 	if l := 30; len(bs) > l {
 		var trailing string
 		switch v.(type) {
 		case string:
 			trailing = ` ..."`
-		case []interface{}:
+		case []any:
 			trailing = " ...]"
-		case map[string]interface{}:
+		case map[string]any:
 			trailing = " ...}"
 		default:
 			trailing = " ..."
@@ -33,7 +33,7 @@ func Preview(v interface{}) string {
 	return string(bs)
 }
 
-func jsonLimitedMarshal(v interface{}, n int) (bs []byte) {
+func jsonLimitedMarshal(v any, n int) (bs []byte) {
 	w := &limitedWriter{buf: make([]byte, n)}
 	defer func() {
 		_ = recover()
@@ -51,7 +51,7 @@ type limitedWriter struct {
 func (w *limitedWriter) Write(bs []byte) (int, error) {
 	n := copy(w.buf[w.off:], bs)
 	if w.off += n; w.off == len(w.buf) {
-		panic(nil)
+		panic(struct{}{})
 	}
 	return n, nil
 }
@@ -59,7 +59,7 @@ func (w *limitedWriter) Write(bs []byte) (int, error) {
 func (w *limitedWriter) WriteByte(b byte) error {
 	w.buf[w.off] = b
 	if w.off++; w.off == len(w.buf) {
-		panic(nil)
+		panic(struct{}{})
 	}
 	return nil
 }
@@ -67,7 +67,7 @@ func (w *limitedWriter) WriteByte(b byte) error {
 func (w *limitedWriter) WriteString(s string) (int, error) {
 	n := copy(w.buf[w.off:], s)
 	if w.off += n; w.off == len(w.buf) {
-		panic(nil)
+		panic(struct{}{})
 	}
 	return n, nil
 }
