@@ -1,11 +1,11 @@
-//go:build !debug
-// +build !debug
+//go:build !gojq_debug
+// +build !gojq_debug
 
 package gojq
 
 type codeinfo struct{}
 
-func (c *compiler) appendCodeInfo(interface{}) {}
+func (c *compiler) appendCodeInfo(any) {}
 
 func (c *compiler) deleteCodeInfo(string) {}
 
